%define major         1
%define libname       %mklibname %{name} %{major}
%define libname_devel %mklibname %{name} -d

Name:           createrepo_c
Summary:        Creates a common metadata repository
Group:          System/Packaging
Version:        1.1.0
Release:        %mkrel 1
License:        GPLv2
URL:            https://github.com/rpm-software-management/createrepo_c
Source0:        https://github.com/rpm-software-management/createrepo_c/archive/%{version}/%{name}-%{version}.tar.gz
BuildRequires:  bzip2-devel
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  file-devel >= 5.40-5
BuildRequires:  glib2-devel >= 2.22.0
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  rpm-devel >= 4.9.0
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  bash-completion
BuildRequires:  pkgconfig(drpm) >= 0.4.1
BuildRequires:  pkgconfig(modulemd-2.0) >= 2.3.0
BuildRequires:  pkgconfig(zck) >= 0.9.11
BuildRequires:  xz
BuildRequires:  zchunk

BuildRequires:  python3-devel
BuildRequires:  python3-nose
BuildRequires:  python3-sphinx

# prevent provides from nonstandard paths:
%define __provides_exclude_from ^(%{python3_sitearch}/.*\\.so)$

# Replaces createrepo
Obsoletes:      createrepo < 0.11.0
Provides:       createrepo = %{version}-%{release}

%description
C implementation of Createrepo.
A set of utilities (createrepo_c, mergerepo_c, modifyrepo_c)
for generating a common metadata repository from a directory of
rpm packages and maintaining it.

%package -n %{libname}
Summary:    Library for repodata manipulation
Group:      System/Libraries

%description -n %{libname}
Libraries for applications using the createrepo_c library
for easy manipulation with a repodata.

%package -n %{libname_devel}
Summary:    Library for repodata manipulation
Group:      Development/C
Provides:   %{name}-devel = %{version}-%{release}
Requires:   pkgconfig

%description -n %{libname_devel}
This package contains the createrepo_c C library and header files.
These development files are for easy manipulation with a repodata.

%package -n python3-%{name}
Summary:    Python 3 bindings for the createrepo_c library
Group:      Development/Python
%{?python_provide:%python_provide python3-%{name}}
Requires:   %{libname}%{?_isa} = %{version}-%{release}

%description -n python3-createrepo_c
Python 3 bindings for the createrepo_c library.


%prep
%autosetup -p1

%build
%cmake \
  -DWITH_LEGACY_HASHES:BOOL=ON \
  -DENABLE_DRPM:BOOL=ON
%cmake_build
%cmake_build --target doc-c

%check
pushd %{_vpath_builddir}
make tests
make ARGS="-V" test
popd

%install
%cmake_install

# To replace createrepo for binaries and manpages
for i in createrepo mergerepo modifyrepo sqliterepo;do
  ln -s %{_bindir}/$i\_c %{buildroot}%{_bindir}/$i
  echo ".so man8/$i\_c.8" > %{buildroot}%{_mandir}/man8/$i\.8
done


%files
%doc README.md
%license COPYING
%{_mandir}/man8/createrepo_c.8*
%{_mandir}/man8/mergerepo_c.8*
%{_mandir}/man8/modifyrepo_c.8*
%{_mandir}/man8/sqliterepo_c.8*
%{_mandir}/man8/createrepo.8*
%{_mandir}/man8/mergerepo.8*
%{_mandir}/man8/modifyrepo.8*
%{_mandir}/man8/sqliterepo.8*
%{_datadir}/bash-completion/completions/
%{_bindir}/createrepo_c
%{_bindir}/mergerepo_c
%{_bindir}/modifyrepo_c
%{_bindir}/sqliterepo_c
%{_bindir}/createrepo
%{_bindir}/mergerepo
%{_bindir}/modifyrepo
%{_bindir}/sqliterepo


%files -n %{libname}
%license COPYING
%{_libdir}/libcreaterepo_c.so.%{major}{,.*}

%files -n %{libname_devel}
%license COPYING
%doc build/doc/html
%{_libdir}/libcreaterepo_c.so
%{_libdir}/pkgconfig/createrepo_c.pc
%{_includedir}/createrepo_c/

%files -n python3-createrepo_c
%license COPYING
%{python3_sitearch}/createrepo_c/
%{python3_sitearch}/%{name}-%{version}-py%{python3_version}.egg-info


%changelog
* Sun Mar 24 2024 wally <wally> 1.1.0-1.mga10
+ Revision: 2051702
- new version 1.1.0

* Tue Jan 30 2024 wally <wally> 1.0.3-1.mga10
+ Revision: 2036339
- new version 1.0.3
- new lib major 1

* Mon Dec 18 2023 papoteur <papoteur> 0.20.1-3.mga10
+ Revision: 2019073
- Mass Rebuild - Python 3.12

* Sun Nov 12 2023 daviddavid <daviddavid> 0.20.1-2.mga10
+ Revision: 2006247
- rebuild for new rpm 4.19.0

* Mon Aug 22 2022 luigiwalser <luigiwalser> 0.20.1-1.mga9
+ Revision: 1879330
- 0.20.1

* Fri May 13 2022 luigiwalser <luigiwalser> 0.20.0-1.mga9
+ Revision: 1858009
- 0.20.0

* Tue Mar 22 2022 luigiwalser <luigiwalser> 0.19.0-1.mga9
+ Revision: 1817899
- 0.19.0
- remove upstream patches

* Thu Feb 17 2022 tv <tv> 0.17.6-3.mga9
+ Revision: 1778409
- Rebuild for python-3.10

* Sun Oct 03 2021 wally <wally> 0.17.6-2.mga9
+ Revision: 1748918
- run all tests as file is fixed

* Sun Oct 03 2021 wally <wally> 0.17.6-1.mga9
+ Revision: 1748911
- new version 0.17.6
- skip failing tests for now
- rebuild for openssl 3.0.0

* Sat Mar 27 2021 tv <tv> 0.16.2-2.mga9
+ Revision: 1710970
- Rebuild for python 3.9

* Sun Nov 29 2020 luigiwalser <luigiwalser> 0.16.2-1.mga8
+ Revision: 1650065
- 0.16.2

* Fri Oct 16 2020 luigiwalser <luigiwalser> 0.16.1-2.mga8
+ Revision: 1636431
- try making better use of cmake macros

* Fri Oct 16 2020 luigiwalser <luigiwalser> 0.16.1-1.mga8
+ Revision: 1636417
- 0.16.1

* Tue Jul 07 2020 ngompa <ngompa> 0.16.0-1.mga8
+ Revision: 1602738
- Update to 0.16.0

* Tue Jul 07 2020 ngompa <ngompa> 0.15.11-1.mga8
+ Revision: 1602720
- Update to 0.15.11

* Wed Feb 19 2020 umeabot <umeabot> 0.15.6-2.mga8
+ Revision: 1543447
- Mageia 8 Mass Rebuild

* Sun Jan 19 2020 ngompa <ngompa> 0.15.6-1.mga8
+ Revision: 1481588
- Update to 0.15.6
+ wally <wally>
- build with new cmake macros

* Sun Dec 08 2019 ngompa <ngompa> 0.15.4-1.mga8
+ Revision: 1465179
- Update to 0.15.4
- Properly replace legacy createrepo

* Mon Sep 09 2019 wally <wally> 0.14.2-3.mga8
+ Revision: 1439010
- rebuild for python3.8

* Sat Aug 31 2019 tv <tv> 0.14.2-2.mga8
+ Revision: 1436033
- obsolete python2 createrepo

* Sat Jun 15 2019 ngompa <ngompa> 0.14.2-1.mga7
+ Revision: 1400068
- Update to 0.14.2

* Tue May 28 2019 ngompa <ngompa> 0.14.1-1.mga7
+ Revision: 1399319
- Update to 0.14.1

* Thu May 16 2019 ngompa <ngompa> 0.14.0-1.mga7
+ Revision: 1397908
- Update to 0.14.0

* Thu May 02 2019 ngompa <ngompa> 0.13.0-1.mga7
+ Revision: 1396121
- Update to 0.13.0

* Mon Apr 01 2019 ngompa <ngompa> 0.12.2-1.mga7
+ Revision: 1384418
- Update to 0.12.2
- Drop Python 2 subpackage

* Tue Jan 08 2019 shlomif <shlomif> 0.12.0-2.mga7
+ Revision: 1352303
- Rebuild for python3 3.7

* Tue Dec 18 2018 ngompa <ngompa> 0.12.0-1.mga7
+ Revision: 1342499
- Rebase to 0.12.0

* Sun Sep 23 2018 umeabot <umeabot> 0.11.0-2.mga7
+ Revision: 1296904
- Mageia 7 Mass Rebuild

* Sat Jun 30 2018 ngompa <ngompa> 0.11.0-1.mga7
+ Revision: 1240892
- Upgrade to createrepo_c 0.11.0
- Drop merged patch

* Fri Sep 01 2017 tv <tv> 0.10.0-5.mga7
+ Revision: 1150486
- rebuild for new rpm

* Sat Aug 05 2017 pterjan <pterjan> 0.10.0-4.mga7
+ Revision: 1135199
- Rebuild for python 3.6

* Thu Jan 12 2017 ngompa <ngompa> 0.10.0-3.mga6
+ Revision: 1081164
- Replace dep filtering patch with improved version (mga#19509)

* Tue Oct 04 2016 ngompa <ngompa> 0.10.0-2.mga6
+ Revision: 1058509
- Add patch to fix dep filtering (mga#19509)

* Wed Jan 06 2016 ngompa <ngompa> 0.10.0-1.mga6
+ Revision: 919958
- Update to 0.10.0

* Wed Oct 21 2015 ngompa <ngompa> 0.9.1-2.mga6
+ Revision: 893842
- Fix Group and Provides for devel subpackage
- Initial import of createrepo_c for Mageia

